package com.example.demo.sujiajie.common.result;

import lombok.Data;

import java.util.Map;

/**
 * 统一返回结果类
 * 用于API接口的统一返回格式
 */
@Data
public class Result<T> {

    private int code;       // 状态码
    private String message; // 消息
    private T data;         // 数据

    /**
     * 成功返回结果（带数据）
     */
    public static <T> Result<T> success(T data) {
        Result<T> result = new Result<>();
        result.code = 200;
        result.message = "success";
        result.data = data;
        return result;
    }

    /**
     * 成功返回结果（不带数据）
     */
    public static <T> Result<T> success() {
        return success(null);
    }

    /**
     * 失败返回结果
     */
    public static <T> Result<T> fail(int code, String message) {
        Result<T> result = new Result<>();
        result.code = code;
        result.message = message;
        result.data = null;
        return result;
    }

    /**
     * 失败返回结果
     */
    public static <T> Result<T> fail(String message) {
        return fail(500, message);
    }


}
