package com.example.demo.sujiajie.config;

import org.modelmapper.ModelMapper;
import org.modelmapper.convention.MatchingStrategies;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * ModelMapper配置类
 * 用于注册ModelMapper为Spring Bean
 */
@Configuration
public class ModelMapperConfig {

    /**
     * 注册ModelMapper为Spring Bean
     */
    @Bean
    public ModelMapper modelMapper() {
        ModelMapper modelMapper = new ModelMapper();
        
        // 配置严格匹配
        modelMapper.getConfiguration()
                .setMatchingStrategy(MatchingStrategies.STRICT)  // 使用严格匹配策略
                .setSkipNullEnabled(true)                        // 跳过空值
                .setFieldMatchingEnabled(true)                   // 启用字段匹配
                .setFieldAccessLevel(org.modelmapper.config.Configuration.AccessLevel.PRIVATE) // 允许访问私有字段
                .setCollectionsMergeEnabled(false);             // 禁用集合合并，避免懒加载问题
        
        return modelMapper;
    }
} 