package com.example.demo.sujiajie.controller;


import com.example.demo.sujiajie.common.exception.TravelPlanException;
import com.example.demo.sujiajie.common.result.Result;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import javax.validation.ConstraintViolationException;
import java.util.HashMap;
import java.util.Map;

/**
 * 全局异常处理器
 * 处理应用程序中的异常并返回统一格式的响应
 */
@RestControllerAdvice
public class ExceptionHandlerController {

    /**
     * 处理行程规划自定义异常
     */
    @ExceptionHandler(TravelPlanException.class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result<?> handleTravelPlanException(TravelPlanException ex) {
        return Result.fail(ex.getCode(), ex.getMessage());
    }

    /**
     * 处理方法参数验证异常
     */
    @ExceptionHandler(MethodArgumentNotValidException.class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result<?> handleMethodArgumentNotValidException(MethodArgumentNotValidException ex) {
        Map<String, String> errors = new HashMap<>();
        ex.getBindingResult().getFieldErrors().forEach(error ->
            errors.put(error.getField(), error.getDefaultMessage())
        );
        return Result.fail(400, "参数验证失败");
    }

    /**
     * 处理约束违反异常
     */
    @ExceptionHandler(ConstraintViolationException.class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    public Result<?> handleConstraintViolationException(ConstraintViolationException ex) {
        Map<String, String> errors = new HashMap<>();
        ex.getConstraintViolations().forEach(violation ->
            errors.put(violation.getPropertyPath().toString(), violation.getMessage())
        );
        return Result.fail(400, "参数验证失败");
    }

    /**
     * 处理其他未捕获的异常
     */
    @ExceptionHandler(Exception.class)
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    public Result<?> handleException(Exception ex) {
        ex.printStackTrace();
        return Result.fail(500, "服务器内部错误: " + ex.getMessage());
    }
}
