package com.example.demo.sujiajie.controller;


import com.example.demo.sujiajie.common.result.Result;
import com.example.demo.sujiajie.dto.request.*;
import com.example.demo.sujiajie.dto.response.TravelPlanResponse;
import com.example.demo.sujiajie.service.TravelPlanService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 行程控制器
 * 处理与行程相关的HTTP请求
 */
@RestController
@RequestMapping("/api/travel-plans")
public class TravelPlanController {

    @Autowired
    private TravelPlanService travelPlanService;

    /**
     * 创建行程
     */
    @PostMapping
    public Result<?> createTravelPlan(@Valid @RequestBody CreateTravelPlanRequest request) {
        travelPlanService.createTravelPlan(request);
        return Result.success();
    }

    /**
     * 更新行程
     */
    @PutMapping
    public Result<?> updateTravelPlan(@Valid @RequestBody UpdateTravelPlanRequest request) {
        travelPlanService.updateTravelPlan(request);
        return Result.success();
    }

    /**
     * 删除行程
     */
    @DeleteMapping("/{planId}")
    public Result<?> deleteTravelPlan(@PathVariable Long planId,
                                     @RequestParam String userId) {
        travelPlanService.deleteTravelPlan(planId, userId);
        return Result.success();
    }

    /**
     * 获取行程详情
     */
    @GetMapping("/{planId}")
    public Result<TravelPlanResponse> getTravelPlanDetail(@PathVariable Long planId,
                                                          @RequestParam String userId) {
        TravelPlanResponse response = travelPlanService.getTravelPlanDetail(planId, userId);
        return Result.success(response);
    }

    /**
     * 获取用户的行程列表
     */
    @GetMapping("/user/{userId}")
    public Result<List<TravelPlanResponse>> getUserTravelPlans(@PathVariable String userId) {
        List<TravelPlanResponse> responses = travelPlanService.getUserTravelPlans(userId);
        return Result.success(responses);
    }

    /**
     * 获取用户参与协作的行程列表
     */
    @GetMapping("/user/{userId}/collaborated")
    public Result<List<TravelPlanResponse>> getUserCollaboratedPlans(@PathVariable String userId) {
        List<TravelPlanResponse> responses = travelPlanService.getUserCollaboratedPlans(userId);
        return Result.success(responses);
    }

    /**
     * 添加行程详情
     */
    @PostMapping("/details")
    public Result<?> addTravelPlanDetail(@Valid @RequestBody AddTravelPlanDetailRequest request) {
        travelPlanService.addTravelPlanDetail(request);
        return Result.success();
    }

    /**
     * 删除行程详情
     */
    @DeleteMapping("/details/{detailId}")
    public Result<?> deleteTravelPlanDetail(@PathVariable Long detailId,
                                          @RequestParam String userId) {
        travelPlanService.deleteTravelPlanDetail(detailId, userId);
        return Result.success();
    }

    /**
     * 添加协作人
     */
    @PostMapping("/collaborators")
    public Result<?> addCollaborator(@Valid @RequestBody AddCollaboratorRequest request) {
        travelPlanService.addCollaborator(request);
        return Result.success();
    }

    /**
     * 删除协作人
     */
    @DeleteMapping("/collaborators")
    public Result<?> removeCollaborator(@RequestParam Long planId,
                                      @RequestParam String collabUserId,
                                      @RequestParam String operatorUserId) {
        travelPlanService.removeCollaborator(planId, collabUserId, operatorUserId);
        return Result.success();
    }

    /**
     * 记录行程操作
     */
    @PostMapping("/operations")
    public Result<?> recordOperation(@Valid @RequestBody RecordOperationRequest request) {
        travelPlanService.recordOperation(request);
        return Result.success();
    }
}
