package com.example.demo.sujiajie.entity;

import lombok.Data;

import javax.persistence.*;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
 * 行程主表实体类
 * 对应数据库中的travel_plans表
 * 存储行程的基本信息，如名称、天数、预算等
 */
@Data
@Entity
@Table(name = "travel_plans")
public class TravelPlan {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long planId;

    private String userId;          // 用户ID
    private String planName;        // 行程名称
    private Integer totalDays;      // 总天数
    private BigDecimal totalBudget; // 总预算
    private String preference;      // 用户偏好
    private Integer status;         // 行程状态：1-草稿 2-已确认 3-已完成

    @Temporal(TemporalType.TIMESTAMP)
    @Column(updatable = false)
    private Date createTime;        // 创建时间

    @Temporal(TemporalType.TIMESTAMP)
    private Date updateTime;        // 更新时间

    @OneToMany(mappedBy = "travelPlan", cascade = CascadeType.ALL, orphanRemoval = true)
    private Set<TravelPlanDetail> details = new HashSet<>(); // 行程详情列表

    @OneToMany(mappedBy = "travelPlan", cascade = CascadeType.ALL, orphanRemoval = true)
    private Set<TravelPlanCollaborator> collaborators = new HashSet<>(); // 协作人列表

    @OneToMany(mappedBy = "travelPlan", cascade = CascadeType.ALL, orphanRemoval = true)
    private Set<TravelPlanOperation> operations = new HashSet<>(); // 操作记录列表
}
