package com.example.demo.sujiajie.repository;


import com.example.demo.sujiajie.entity.TravelPlan;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 行程主表数据访问接口
 * 提供对travel_plans表的CRUD操作
 */
@Repository
public interface TravelPlanRepository extends JpaRepository<TravelPlan, Long> {

    /**
     * 根据用户ID查询行程列表
     */
    List<TravelPlan> findByUserId(String userId);

    /**
     * 查询用户参与协作的行程列表
     */
    @Query("SELECT p FROM TravelPlan p JOIN p.collaborators c WHERE c.collabUserId = ?1")
    List<TravelPlan> findCollaboratedPlans(String userId);

    /**
     * 查询行程详情（只获取基本信息）
     */
    @Query("SELECT p FROM TravelPlan p WHERE p.planId = ?1")
    TravelPlan findWithDetailsById(Long planId);

    /**
     * 查询行程详情（包含详情列表）
     */
    @Query("SELECT p FROM TravelPlan p LEFT JOIN FETCH p.details WHERE p.planId = ?1")
    TravelPlan findWithDetailListById(Long planId);

    /**
     * 查询行程详情（包含协作者列表）
     */
    @Query("SELECT p FROM TravelPlan p LEFT JOIN FETCH p.collaborators WHERE p.planId = ?1")
    TravelPlan findWithCollaboratorsById(Long planId);

    /**
     * 查询行程详情（包含操作记录列表）
     */
    @Query("SELECT p FROM TravelPlan p LEFT JOIN FETCH p.operations WHERE p.planId = ?1")
    TravelPlan findWithOperationsById(Long planId);
}
