package com.example.demo.sujiajie.service;


import com.example.demo.sujiajie.dto.request.*;
import com.example.demo.sujiajie.dto.response.TravelPlanResponse;
import com.example.demo.sujiajie.entity.TravelPlan;

import java.util.List;

/**
 * 行程服务接口
 * 定义行程管理的业务方法
 */
public interface TravelPlanService {

    /**
     * 创建行程
     */
    TravelPlan createTravelPlan(CreateTravelPlanRequest request);

    /**
     * 更新行程
     */
    TravelPlan updateTravelPlan(UpdateTravelPlanRequest request);

    /**
     * 删除行程
     */
    void deleteTravelPlan(Long planId, String userId);

    /**
     * 获取行程详情
     */
    TravelPlanResponse getTravelPlanDetail(Long planId, String userId);

    /**
     * 获取用户的行程列表
     */
    List<TravelPlanResponse> getUserTravelPlans(String userId);

    /**
     * 获取用户参与协作的行程列表
     */
    List<TravelPlanResponse> getUserCollaboratedPlans(String userId);

    /**
     * 添加行程详情
     */
    void addTravelPlanDetail(AddTravelPlanDetailRequest request);

    /**
     * 删除行程详情
     */
    void deleteTravelPlanDetail(Long detailId, String userId);

    /**
     * 添加协作人
     */
    void addCollaborator(AddCollaboratorRequest request);

    /**
     * 删除协作人
     */
    void removeCollaborator(Long planId, String collabUserId, String operatorUserId);

    /**
     * 记录行程操作
     */
    void recordOperation(RecordOperationRequest request);

    /**
     * 检查用户是否有访问行程的权限
     */
    boolean checkPermission(Long planId, String userId, int requiredPermission);
}
